//
//  Top3TableViewController.m
//  Game
//
//  Created by Santiago Pavón on 15/11/13.
//  Copyright (c) 2013 UPM. All rights reserved.
//

#import "Top3TableViewController.h"

#define GAME_URL @"http://localhost:3000/scores/top3.xml"


@interface Top3TableViewController () <NSXMLParserDelegate>

@property (nonatomic,strong) NSArray * top3Scores;
@property (weak, nonatomic) IBOutlet UIBarButtonItem *refreshButton;

// Array para almacenar las puntuaciones
@property (nonatomic,strong) NSMutableArray *top3ScoresNew;

// Parser XML
@property (nonatomic,strong) NSMutableDictionary *scoreNew;
@property (nonatomic,strong) NSString *keyNew;
@property (nonatomic,strong) NSMutableString *valueNew;

@end

@implementation Top3TableViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
    
    [self getTop3:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}



- (IBAction)getTop3:(UIBarButtonItem *)sender {
    
    self.title = @"Descargando ...";
    self.refreshButton.enabled = NO;
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:YES];
	
    
    NSString *escapedURL = [GAME_URL stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    NSURL *url = [NSURL URLWithString:escapedURL];
    
    NSXMLParser * xmlParser = [[NSXMLParser alloc] initWithContentsOfURL:url];
	
    [xmlParser setDelegate:self];
    [xmlParser setShouldResolveExternalEntities:NO];
    if ([xmlParser parse]) {
        self.title = @"Top 3";
        self.top3Scores = self.top3ScoresNew;
        [self.tableView reloadData];
    } else {
        self.title = @"Error datos incorrectos";
    }
    
    self.refreshButton.enabled = YES;
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:NO];
}

#pragma mark - XML Parser Delegate

- (void) parser:(NSXMLParser *)parser
didStartElement:(NSString *)elementName
   namespaceURI:(NSString *)namespaceURI
  qualifiedName:(NSString *)qName
     attributes:(NSDictionary *)attributeDict {
	
    self.keyNew = nil;
    self.valueNew = nil;
	
    if ([elementName isEqualToString:@"scores"]) {
        self.top3ScoresNew = [NSMutableArray array];
    } else if ( [elementName isEqualToString:@"score"] ) {
        self.scoreNew = [NSMutableDictionary dictionary];
    } else if ( [elementName isEqualToString:@"total"] ) {
        self.keyNew = @"total";
    } else if ( [elementName isEqualToString:@"name"] ) {
        self.keyNew = @"name";
    }
}

- (void) parser:(NSXMLParser *)parser
foundCharacters:(NSString *)string {
	
    if (self.keyNew) {
        if ( ! self.valueNew) {
            self.valueNew = [NSMutableString string];
        }
        [self.valueNew appendString:string];
    }
}

- (void) parser:(NSXMLParser *)parser
  didEndElement:(NSString *)elementName
   namespaceURI:(NSString *)namespaceURI
  qualifiedName:(NSString *)qName {
	
    if ([elementName isEqualToString:@"scores"]) {
        // ya hemos parseado todo.
    } else if ([elementName isEqualToString:@"score"]) {
        // Guardar nueva puntuacion.
        [self.top3ScoresNew addObject:self.scoreNew];
    } else if ([elementName isEqualToString:@"total"] ||
               [elementName isEqualToString:@"name"])  {
        [self.scoreNew setValue:self.valueNew forKey:self.keyNew ];
    }
    self.keyNew = nil;
    self.valueNew = nil;
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}



- (NSInteger) tableView:(UITableView *)tableView
  numberOfRowsInSection:(NSInteger)section
{
    return [self.top3Scores count];
}



- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Score Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier
                                                            forIndexPath:indexPath];
    
    NSDictionary *dic = self.top3Scores[indexPath.row];
    
    cell.textLabel.text       = dic[@"name"];
    cell.detailTextLabel.text = dic[@"total"];

    return cell;
}







/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}
*/

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

/*
#pragma mark - Navigation

// In a story board-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}

 */

@end
